#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <stdio.h>
#include <gtk/gtk.h>

#include <time.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"
#include "global.h"


int file_exist(char *filename);


// shows info window
void
on_buttonInfo_clicked                  (GtkButton       *button,
                                        gpointer         user_data)
{
	gtk_widget_show (infoWindow);
}


// cancel button in pref. window, reset old pref. value
void
on_buttonCancel_clicked                (GtkButton       *button,
                                        gpointer         user_data)
{
	GtkWidget *connectCommand,*disconnectCommand,*interfaceName;
	
	
	connectCommand = lookup_widget(mainWindow,"connectCommand");
	gtk_entry_set_text(GTK_ENTRY(connectCommand),connectCommandOld);
	
	disconnectCommand = lookup_widget(mainWindow,"disconnectCommand");
	gtk_entry_set_text(GTK_ENTRY(disconnectCommand),disconnectCommandOld);
	
	interfaceName = lookup_widget(mainWindow,"interfaceName");
	gtk_entry_set_text(GTK_ENTRY(interfaceName),interfaceNameOld);
	
	gtk_widget_hide (mainWindow);
}


// ok button in pref. window, check new command and interface (if changed)
void
on_buttonOK_clicked                    (GtkButton       *button,
                                        gpointer         user_data)
{
	
	gchar *filenameconnect,*filenamedisconnect,*pppon, *pppoff,*interface,*freemem;
	GtkWidget *connectCommand,*disconnectCommand, *interfaceName;
	
	connectCommand = lookup_widget(mainWindow,"connectCommand");
	disconnectCommand = lookup_widget(mainWindow,"disconnectCommand");
	interfaceName = lookup_widget(mainWindow,"interfaceName");
	pppon = (gchar *)(gtk_entry_get_text(GTK_ENTRY(connectCommand)));
	pppoff = (gchar *)(gtk_entry_get_text(GTK_ENTRY(disconnectCommand)));
	interface = (gchar *)(gtk_entry_get_text(GTK_ENTRY(interfaceName)));
	filenameconnect = g_build_filename(pppon, NULL);
	filenamedisconnect = g_build_filename(pppoff, NULL);
	if((!file_exist(filenameconnect)) && filenameconnect[0] != 0 ) 
	{
		//printf("Invalid connect command\n");
		gtk_label_set_text(GTK_LABEL(errorMessage),_("Invalid connect command"));
        gtk_widget_show(errorDialog);
		return;
	}
	if((!file_exist(filenamedisconnect)) && filenamedisconnect[0] != 0 ) 
	{
		//printf("Invalid disconnect command\n");
		gtk_label_set_text(GTK_LABEL(errorMessage),_("Invalid disconnect command"));
        gtk_widget_show(errorDialog);
		return;
	}
	if( interface[0] == 0)
	{
		//printf("Invalid interface name\n");
		gtk_label_set_text(GTK_LABEL(errorMessage),_("Invalid interface name"));
        gtk_widget_show(errorDialog);
		return;
	}

	// refresh global var interfacenameGlobal
	freemem = interfacenameGlobal;
	interfacenameGlobal = g_build_filename((gchar *)interface,NULL);
	g_free(freemem);
	
	save_pref();

	gtk_widget_hide (mainWindow);
}

int file_exist(char *filename)
{
	FILE *lock_file_descriptor;
	int count,len,i;
	gchar filenamecut[strlen(filename)+1];
	
	i=0;
	len=strlen(filename);
	
	// cuts parameters
	while(filename[i]!=' ' && i<len)	
	{
		i++;
	}
	strncpy(filenamecut,filename,i);
	filenamecut[i]=0;
	
	// check if file exists
	if((lock_file_descriptor = fopen(filenamecut,"r"))==NULL)
	{
		// file not exists
	    return FALSE;
	}
	else
	{
		// file exists
		fclose(lock_file_descriptor);
		return TRUE;
	}
}


// button close in informations window
void
on_buttonChiudi_clicked                (GtkButton       *button,
                                        gpointer         user_data)
{
	gtk_widget_hide (infoWindow);
}


// show pref window in contextual menu, remember old values in case of cancel button press
void
on_preferenze1_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkWidget *connectCommand,*disconnectCommand,*interfaceName;
	
	connectCommand = lookup_widget(mainWindow,"connectCommand");
	disconnectCommand = lookup_widget(mainWindow,"disconnectCommand");
	interfaceName = lookup_widget(mainWindow,"interfaceName");
	
	g_free(connectCommandOld);
	g_free(disconnectCommandOld);
	g_free(interfaceNameOld);
	
	connectCommandOld = g_build_filename((gchar *)(gtk_entry_get_text(GTK_ENTRY(connectCommand))),NULL);
	disconnectCommandOld = g_build_filename((gchar *)(gtk_entry_get_text(GTK_ENTRY(disconnectCommand))),NULL);
	interfaceNameOld = g_build_filename((gchar *)(gtk_entry_get_text(GTK_ENTRY(interfaceName))),NULL);
	
	gtk_widget_show (mainWindow);
}


// show information window in contextual menu
void
on_informazioni1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	gtk_widget_show (infoWindow);
}


// exit in contextual menu, terminates mynetmonitor
void
on_esci1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{		     
	fflush(logFD);
	exit(0);
}


// start connect command (if current status is disconnected)
void
on_connect_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	gchar *command;
	const gchar *pppon;
	GtkWidget *connectCommand;
	
	if( isonline != 1 )
	{
		connectCommand = lookup_widget(mainWindow,"connectCommand");
		pppon = (const gchar *)(gtk_entry_get_text(GTK_ENTRY(connectCommand)));
		command = g_build_filename(pppon, NULL);
		system(command);
	}
}


// // start disconnect command (if current status is connected)
void
on_disconnect_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	gchar *command;
	const gchar *pppoff; 
	GtkWidget *disconnectCommand;
	
	if( isonline == 1)
	{
		disconnectCommand = lookup_widget(mainWindow,"disconnectCommand");
		pppoff = (const gchar *)(gtk_entry_get_text(GTK_ENTRY(disconnectCommand)));
		command = g_build_filename(pppoff, NULL);
		okdown = 1; // disable disconnect message window
		disconnectCommandRunning = 1; // disconnect command is running
		system(command);
	}
}


// ok button in error dialog, hides error dialog window
void
on_okbutton1_clicked                   (GtkButton       *button,
                                        gpointer         user_data)
{
	gtk_widget_hide(errorDialog);
}


// Hides instead of delete pref. window 
gboolean
on_mainWindow_delete_event             (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
  on_buttonCancel_clicked(NULL,NULL);
  return TRUE;
}


// Hides instead of delete info window
gboolean
on_infoWindow_delete_event             (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
  gtk_widget_hide (infoWindow);
  return TRUE;
}


// Hides instead of delete error dialog window
gboolean
on_errorDialog_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
  gtk_widget_hide(errorDialog);
  return TRUE;
}
